<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>アプリケーションプロキシ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシの種類</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP アドレス</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>設定後にランチャのアプリケーションコンテキストメニューで「プロキシーを使う」をクリックしてください</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保存</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無効なIPアドレスです</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>無効なポートです</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>切断</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>削除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保存</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>この設定を削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>有線接続 %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE 接続 %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>新しい VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN の種類</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>アプリケーションプロキシ</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>個人的なホットスポット</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>ネットワークの詳細</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>システムプロキシ</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有線ネットワークアダプター</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ネットワーク接続を追加</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>無線ネットワークアダプター</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>非表示のネットワークへ接続</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE 接続を作成</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN の状態</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN を作成</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN をインポート</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシの種類</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>設定 URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP アドレス</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>ホットスポットを作成</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>インターフェース</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>プライマリ DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>無効なDNSアドレスです</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>イーサーネット</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>バインドされていません</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>デバイスの MAC アドレス</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>複製 MAC アドレス</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU をカスタマイズ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>この名前はすでに存在します</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自動接続</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>設定を追加</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>ホットスポットを作成</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP アドレス</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無効なIPアドレスです</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無効なネットマスクです</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無効なIPアドレスです</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>無視</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP アドレス</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>一致するリソースにのみ適用されます</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>メソッド</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無効なIPアドレスです</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無効なネットマスクです</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>メソッド</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>無視</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>ネットワークの詳細</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>システムプロキシ</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>アプリケーションプロキシ</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>ネットワークの詳細</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>ネットワークマネージャーで設定</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>個人的なホットスポット</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>サービス</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 認証を拒否</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD データを圧縮しない</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>デフレートデータを圧縮しない</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ヘッダーを圧縮しない</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>プロトコルフィールドを圧縮しない</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>アドレス／コントロールを圧縮しない</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP エコーパケットを送る</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE を使う</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128 ビット MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE 接続を作成</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>システムプロキシ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保存</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシの種類</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP プロキシ</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS プロキシ</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP プロキシ</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS プロキシ</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>上記のホストとドメインでプロキシ設定を無視</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>設定 URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>トンネル TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>保護された EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>このユーザーのパスワードを保存する</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>全ユーザーのパスワードを保存する</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>常に確認する</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>認証済み</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>両方</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>バージョン 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>バージョン 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP 認証</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>アイデンティティ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー認証</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名 ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>プロビジョニング</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC ファイル</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner 認証</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP バージョン</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>プライベートパスワード</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>無効なパスワードです</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA／WPA2 パーソナル</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>キー</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>セキュリティ確認</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>無効なパスワードです</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA／WPA2 パーソナル</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA／WPA2 エンタープライズ</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共有鍵</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>システムを開く</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>認証</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>キー</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>高度な VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>ゲートウェイポートのカスタマイズ</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>ゲートウェイポート</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>認識間隔のカスタマイズ</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>認識間隔</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO データ圧縮を使う</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP 接続を使う</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP デバイスを使う</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>トンネル MTU のカスタマイズ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP フラグメントサイズのカスタマイズ</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP フラグメントのサイズ</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tunnel TCP MSS の禁止</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>リモートホストをランダムにする</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>高度な VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (デフォルト)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>ネットスクリーン</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全 (デフォルト)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱い</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>可能時は NAT-T (デフォルト)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>常に NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH グループ 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH グループ 2 (デフォルト)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH グループ 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>サーバー (デフォルト)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH グループ 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>ドメイン</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>ベンダー</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>暗号化</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NATトラバースモード</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH グループ</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>前方秘匿性</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>ローカルポート</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>デッドピア検知を無効化</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation> IPsec の有効</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>グループ名</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>グループ ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>事前共有キー</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>フェーズ1アルゴリズム</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>フェーズ2アルゴリズム</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>プロキシ</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Secure Desktop トロイを許可</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD スクリプト</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー認証</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>キーパスフレーズに FSID を使用</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>認証 (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>パスワードで認証 (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>静的鍵</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>保存済み</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>確認する</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>認証の種類</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー認証</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>プライベートパスワード</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>キーの方向をカスタマイズ</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>キーの方向</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>リモート IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>ローカル IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>すべて有効 (デフォルト)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 ビット (安全性が低い)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 ビット (最も安全)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 認証を拒否</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD データを圧縮しない</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>デフレートデータを圧縮しない</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ヘッダーを圧縮しない</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>プロトコルフィールドを圧縮しない</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>アドレス／コントロールを圧縮しない</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP エコーパケットを送る</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE を使う</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN の状態</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN を作成</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN をインポート</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>インポートエラー</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>ファイルエラー</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN プロキシ</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシの種類</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>サーバー IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失敗時に再試行</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA ファイル</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>証明書の警告を無視</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS ホスト名の拡張機能を使う</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN セキュリティ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC 認証</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>保存済み</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>確認する</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT ドメイン</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN プロキシ</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>サーバー IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH エージェント</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>スマートカード</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>事前共有キー</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>認証の種類</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー認証</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>内部 IP アドレスを要求</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP カプセル化を強制</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP 圧縮を使う</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>カスタム暗号提案を有効にする</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 認証</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>クライアント</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>サーバー</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>サブジェクトマッチ</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>リモート証明書の種類</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>キーファイル</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>キーの方向をカスタマイズ</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>キーの方向</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>保存済み</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>確認する</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>省略可能</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>グループ名</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>グループパスワード</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>ハイブリッド認証を使用</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ファイル</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>始めに、ネットワークケーブルを接続してください</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有線ネットワークアダプター</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ネットワーク接続を追加</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>設定を選択</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>無線ネットワークアダプター</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>ホットスポットを閉じる</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>無線ネットワークに接続したい場合は、まずホットスポットを無効にしてください</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>非表示のネットワークへ接続</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>バインドされていません</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>デバイスの MAC アドレス</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU をカスタマイズ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>プロトコル</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>セキュリティタイプ</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>インターフェース</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>プライマリ DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認証中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP アドレスを取得中</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>接続済み</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線ネットワーク %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線接続 %1</translation>
    </message>
</context>
</TS>